/*
 * $Id:$
 */

/*
 * Harbour Project source code:
 * Greek module
 *
 * Copyright 2000 Manos Aspradakis <maspr@otenet.gr>
 * www - http://www.harbour-project.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version, with one exception:
 *
 * The exception is that if you link the Harbour Runtime Library (HRL)
 * and/or the Harbour Virtual Machine (HVM) with other files to produce
 * an executable, this does not by itself cause the resulting executable
 * to be covered by the GNU General Public License. Your use of that
 * executable is in no way restricted on account of linking the HRL
 * and/or HVM code into it.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA (or visit
 * their web site at http://www.gnu.org/).
 *
 */
/*
 * The following parts are Copyright of the individual authors.
 * www - http://www.harbour-project.org
 *
 * Copyright 2000 Luiz Rafael Culik <culik@sl.conex.net>
 *    Porting this library to Harbour
 *
 * See doc/license.txt for licensing terms.
 *
 */


#include "default.ch"
#include "simpleio.ch"
#include "lowFiles.ch"
#include "html.ch"

STATIC saGreek := {}

#define GREEK_ALPHABET  {;
                         "","","","","","","","","","","","","","","","","","","","","","","","",;   // A-
                         "","","","","","","","","","","","","","","","","","","","","","","","",;   // -
                         "","","","","","","","","","", "","","","","","","","","" ;   // -
                        }



/****
*
*     gr2Html.prg
*
*     Converts ASCII files with international character sets to HTML
*
*     This example uses greek. It may be easily converted to other languages.
*     The GREEK_ALPHABET array is a representation of the greek alphabet
*
*
*/

PROC Main( cFile, cCmd )
LOCAL oHtm, nH

DEFAULT cFile := ""
DEFAULT cCmd  := ""

cFile := UPPER( cFile )
cCmd  := UPPER( cCmd  )

IF !FILE( cFile )
   ? "File '"+ cFile +"' not found !!!"
   ? ""
   RETURN
ENDIF

nH := FOpen( cFile )

IF nH <= 0

   ? "Error opening file !!!"
   ? ""
   ? "gr2Html <file> [/W] [/E] [/P]"
   ? ""
   ? "/W  Open file with Winword.exe"
   ? "/E  Open file with Internet Explorer"
   ? ""
   RETURN
ENDIF

DEFINE HTML ;
       FILE "Out.htm" ;
       TITLE ( cFile ) ;
       OF oHtm

     ohtm:write( "<PRE>"+CRLF() )
WHILE !FEOF( nH )

     ohtm:write( greek2Html( FReadline( nH ) )+"<BR>" )

ENDDO
     ohtm:write( "</PRE>"+CRLF() )

Ohtm:close()

? "Ok ( File saved to 'OUT.HTM' )"
? ""

IF "W" $ cCmd
   SWPRUNCMD( "START WINWORD.EXE Out.Htm" )
ELSEIF "E" $ cCmd
   SWPRUNCMD( "START Out.Htm" )
ELSEIF "P" $ cCmd
   SWPRUNCMD( "START WORDPAD.EXE Out.Htm" )
ENDIF

RETURN



/****
*
*     InitGreek()
*
*     Initializes the international languages support.
*
*     Uses GREEK_ALPHABET array as a match pattern. Replace with your
*     own character set.
*/

FUNCTION initGreek()
LOCAL i,n
LOCAL aGreek := GREEK_ALPHABET
LOCAL aArr   := ARRAY( 255 )

FOR i = 1 TO 255
    aArr[i] := CHR(i)
NEXT

n := 1
FOR i = 128 TO 175
    aArr[i] := aGreek[n]
    n++
NEXT

FOR i=224 to 240
    aArr[i] := aGreek[n]
    n++
next
aArr[244] := aGreek[n] ; n++
aArr[245] := aGreek[n]

RETURN( aArr )



/****
*
*     Greek2Html()
*
*     Converts International characters to HTML
*/

FUNCTION Greek2Html( cText )
LOCAL i, cStr := ""

IF EMPTY( saGreek )
   saGreek := initGreek()
ENDIF
FOR I=1 to LEN( cText )
   cStr += saGreek[ ASC( substr( cText, i, 1 ) ) ]
NEXT

RETURN( cStr )




//
FUNCTION FReadline( nH, nSize )
//
LOCAL cString, nCurrent, nCr

DEFAULT nSize := 1024

IF nSize <= 0
   RETURN( "" )
ENDIF

nCurrent :=  FSEEK( nH, 0, 1 )
cString  :=  FREADSTR( nH, nSize )
nCr      :=  AT( CHR(13), cString )

FSEEK( nH,nCurrent,0 )
FSEEK( nH,nCr+1,1 )

RETURN SUBSTR( cString, 1, nCr-1 )



/***
*
*  FSize( <nHandle> ) --> nBytes
*
*  Return the size of a binary file
*
*/
FUNCTION FSize( nHandle )

   LOCAL nCurrent
   LOCAL nLength

   // Get file position
   nCurrent := FPos( nHandle )

   // Get file length
   nLength := FSEEK( nHandle, 0, FS_END )

   // Reset file position
   FSEEK( nHandle, nCurrent )

   RETURN ( nLength )


